@@ -12,11 +12,11 @@ class ApplicationBuilder(dm.builder.ApplicationBuilder):
     
     def construct(self):
         super(ApplicationBuilder, self).construct()
-        features.register('UrlBuilderProject', self.findUrlBuilderProject())
+        features.register('UrlScheme', self.findUrlScheme())
 
-    def findUrlBuilderProject(self):
+    def findUrlScheme(self):
         import kforge.url
-        return kforge.url.UrlBuilderProject()
+        return kforge.url.UrlScheme()
  
     #
     # Replace features.
