@@ -24,11 +24,11 @@ class TestProjectWithAdministratorCreate(TestCase):
         )
 
     def tearDown(self):
-        if self.projectName in self.registry.projects.all:
+        if self.projectName in self.registry.projects.getAll():
             project = self.registry.projects[self.projectName]
             project.delete()
             project.purge()
-        if self.personName in self.registry.persons.all:
+        if self.personName in self.registry.persons.getAll():
             person = self.registry.persons[self.personName]
             person.delete()
             person.purge()
