@@ -22,32 +22,41 @@ class TestMemberCRUD(KuiTestCase):
         self.deletePerson()
 
     def test_list(self):
+        offset = self.url_scheme.url_for('project.admin',
+                project=self.kuiProjectName, subcontroller='members')
         self.getAssertContent(
-            '/project/%s/members/' % self.kuiProjectName,
+            offset,
             'Project Members'
         )
         self.getAssertContent(
-            '/project/%s/members/' % self.kuiProjectName,
+            offset,
             self.kuiPersonName
         )
 
     def test_create(self):
+        offset = self.url_scheme.url_for('project.admin',
+                project=self.kuiProjectName, subcontroller='members',
+                action='create')
         self.getAssertContent(
-            '/project/%s/members/create/' % self.kuiProjectName,
+            offset,
             'Create member'
         )
 
     def test_update(self):
+        offset = self.url_scheme.url_for('project.admin',
+                project=self.kuiProjectName, subcontroller='members',
+                action='edit', id=self.kuiPersonName)
         self.getAssertContent(
-            '/project/%s/members/%s/edit/' % (self.kuiProjectName, self.kuiPersonName),
+            offset,
             'Edit member'
         )
 
     def test_delete(self):
+        offset = self.url_scheme.url_for('project.admin',
+                project=self.kuiProjectName, subcontroller='members',
+                action='delete', id=self.kuiPersonName)
         self.getAssertContent(
-            '/project/%s/members/%s/delete/' % (
-                self.kuiProjectName, self.kuiPersonName
-            ),
+            offset,
             'Delete member'
         )
 
