@@ -13,7 +13,7 @@ class Person(dm.dom.person.Person):
         super(Person, self).delete()
 
     def purge(self):
-        for member in self.memberships.all:
+        for member in self.memberships.getAll():
             member.delete()
             member.purge()
         super(Person, self).purge()
