@@ -6,7 +6,7 @@ def getPlugins():
 class Project(StandardObject):
     "Registered project."
 
-    searchAttributeNames = ['name', 'title']
+    searchAttributeNames = ['name', 'title', 'description']
 
     title       = String(default='')
     description = String(default='')
@@ -15,26 +15,26 @@ class Project(StandardObject):
     services    = HasMany('Service', 'name')
 
     def delete(self):
-        for member in self.members.all:
+        for member in self.members.getAll():
             member.delete()
-        for service in self.services.all:
+        for service in self.services.getAll():
             service.delete()
         super(Project, self).delete()
 
     def undelete(self):
         super(Project, self).undelete()
-        for member in self.members.all:
+        for member in self.members.getAll():
             member.undelete()
-        for service in self.services.all:
+        for service in self.services.getAll():
             service.undelete()
 
     def purge(self):
         for license in self.licenses:
             license.delete()
-        for service in self.services.all:
+        for service in self.services.getAll():
             service.delete()
             service.purge()
-        for member in self.members.all:
+        for member in self.members.getAll():
             member.delete()
             member.purge()
         super(Project, self).purge()
