@@ -9,7 +9,7 @@ class Service(NamedStatefulObject):
     plugin  = HasA('Plugin')
     project = HasA('Project')
 
-    projectUrls = RequiredFeature('UrlBuilderProject')
+    projectUrls = RequiredFeature('UrlScheme')
 
     def checkProjectPluginDir(self):
         if not self.hasProjectPluginDir():
