@@ -1,5 +1,7 @@
 import dm.plugin.base
 import os
+from dm.strategy import FindProtectionObject
+from dm.strategy import CreateProtectionObject
 
 class AbstractServicePlugin(dm.plugin.base.PluginBase):
 
@@ -17,23 +19,23 @@ class AbstractServicePlugin(dm.plugin.base.PluginBase):
             os.makedirs(projectPluginPath)
     
     def backup(self, service, backupPathBuilder):
+        """Backup the plugged-in application service.
+
+        @backupPathBuilder: any object supporting a function getServicePath.
+        """
         pass
     
     def onCreate(self):
-        protectionClass = self.registry.getDomainClass('ProtectionObject')
-        protectedName = protectionClass.makeProtectedName(self.domainObject)
-        protectionObjects = self.registry.protectionObjects
-        protectionObject = protectionObjects.create(protectedName)
+        createObject = CreateProtectionObject(self.domainObject)
+        protectionObject = createObject.create()
         import kforge.command
         cmd = kforge.command.GrantStandardProjectAccess(protectionObject)
         cmd.execute()
     
     def onDelete(self):
-        protectionClass = self.registry.getDomainClass('ProtectionObject')
-        protectedName = protectionClass.makeProtectedName(self.domainObject)
-        protectionObjects = self.registry.protectionObjects
-        if protectedName in protectionObjects:
-            protectionObject = protectionObjects[protectedName]
+        findObject = FindProtectionObject(self.domainObject)
+        protectionObject = findObject.find()
+        if protectionObject:
             protectionObject.delete()
 
     def getUserHelp(self, service):
