@@ -8,6 +8,7 @@ import os
 import shutil
 
 import kforge.plugin.base
+from dm.strategy import FindProtectionObject
 
 class Plugin(kforge.plugin.base.SingleServicePlugin):
     
@@ -35,10 +36,8 @@ class Plugin(kforge.plugin.base.SingleServicePlugin):
         Only allow members to read: dav plugin gives access to all project data.
         """
         super(Plugin, self).onCreate()
-        protectionClass = self.registry.getDomainClass('ProtectionObject')
-        protectedName = protectionClass.makeProtectedName(self.domainObject)
-        protectionObjects = self.registry.protectionObjects
-        protectionObject = protectionObjects[protectedName]
+        findObject = FindProtectionObject(self.domainObject)
+        protectionObject = findObject.find()
         read = protectionObject.permissions[self.registry.actions['Read']]
         friend = self.registry.roles['Friend']
         if read in friend.grants:
