@@ -1,7 +1,7 @@
 from dm.re import *
 
 projectName = '[0-9a-z]+'
-reservedProjectName = 'home|create|find|search|update|delete|purge'
+reservedProjectName = 'home|create|find|search|update|delete|purge|admin|person|project|login|media'
 pluginName = '[0-9a-z\_\-]+'
 reservedPluginName = 'home|create|find|search|update|delete|purge'
 serviceName = '[\w\_\-]+'
